---
feature_story: FS_62_25_92_06
feature_title: generated config
feature_status: TEST
---

Some test mode cannot use mocked config - see FS_66_17_43_42 test infra
when client or server is `out` of current test scenario process.

But we still need to configure different behaviors of client and server under test.
Example use case is to disable some time-dependent unpredictable output
generated by `out` of process client (e.g. by spinner for FS_14_59_14_06 pending requests).

One approach to specify different config could be direct modification of default config files:
*   modify them before running the test
*   restore them after running the test

This can be messy (especially to restore the files which contain extra comments and spaces)
as manual and auto changes can be mixed.

The alternative way (chosen in this feature) is to generate required config files in a temporary dir and
set `ARGRELAY_CONF_BASE_DIR` (see FS_47_63_35_61 env vars and FS_16_07_78_84 conf dir priority)
to load them from there (and clean up after).

File generation should be explicitly mutually exclusive with file mocking to avoid confusion -
either mock config or generated config should be used in test setup, not both.
